@@ -2,6 +2,9 @@
 import locale
 import itertools
 import gettext
+import os
+import sys
+import ctypes
 from pkg_resources import resource_filename
 
 # internal modules
@@ -14,8 +17,22 @@ LOCALEDIR = resource_filename("polt", "locale")
 
 # set up localization
 locale.setlocale(locale.LC_ALL, "")
-for mod in [locale, gettext]:
-    mod.bindtextdomain(GETTEXT_DOMAIN, LOCALEDIR)
+
+# taken from https://stackoverflow.com/a/42577134
+try:
+    if hasattr(locale, "bindtextdomain"):
+        libintl = locale
+    elif os.name == "nt":
+        libintl = ctypes.cdll.LoadLibrary("libintl-8.dll")
+    elif sys.platform == "darwin":
+        libintl = ctypes.cdll.LoadLibrary("libintl.dylib")
+
+    libintl.bindtextdomain(GETTEXT_DOMAIN, LOCALEDIR)
+
+except (OSError, AttributeError):
+    pass
+
+gettext.bindtextdomain(GETTEXT_DOMAIN)
 gettext.textdomain(GETTEXT_DOMAIN)
 gettext.install(GETTEXT_DOMAIN, localedir=LOCALEDIR)
 
